@@ -19,22 +19,18 @@
 
 #include "dolphinitemlistview.h"
 
+#include "dolphin_compactmodesettings.h"
+#include "dolphin_detailsmodesettings.h"
 #include "dolphin_generalsettings.h"
 #include "dolphin_iconsmodesettings.h"
-#include "dolphin_detailsmodesettings.h"
-#include "dolphin_compactmodesettings.h"
 #include "dolphinfileitemlistwidget.h"
-
-#include <kitemviews/kfileitemlistview.h>
-#include <kitemviews/kfileitemmodel.h>
-#include <kitemviews/kitemlistcontroller.h>
-#include <kitemviews/kitemliststyleoption.h>
-
-
-#include <views/viewmodecontroller.h>
-
+#include "kitemviews/kfileitemmodel.h"
+#include "kitemviews/kitemlistcontroller.h"
+#include "views/viewmodecontroller.h"
 #include "zoomlevelinfo.h"
 
+#include <KIO/PreviewJob>
+
 
 DolphinItemListView::DolphinItemListView(QGraphicsWidget* parent) :
     KFileItemListView(parent),
@@ -94,11 +90,7 @@ void DolphinItemListView::readSettings()
     updateGridSize();
 
     const KConfigGroup globalConfig(KSharedConfig::openConfig(), "PreviewSettings");
-    const QStringList plugins = globalConfig.readEntry("Plugins", QStringList()
-                                                       << "directorythumbnail"
-                                                       << "imagethumbnail"
-                                                       << "jpegthumbnail");
-    setEnabledPlugins(plugins);
+    setEnabledPlugins(globalConfig.readEntry("Plugins", KIO::PreviewJob::defaultPlugins()));
 
     endTransaction();
 }
